@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@ public:
     CustomToolsPluginPrivate()
     {
     }
+    bool enabled = false;
 };
 
 CustomToolsPlugin::CustomToolsPlugin(QObject *parent)
@@ -38,3 +39,29 @@ CustomToolsPlugin::~CustomToolsPlugin()
 {
     delete d;
 }
+
+
+bool CustomToolsPlugin::hasConfigureDialog() const
+{
+    return false;
+}
+
+void CustomToolsPlugin::showConfigureDialog(QWidget *parent)
+{
+    Q_UNUSED(parent);
+}
+
+QString CustomToolsPlugin::description() const
+{
+    return {};
+}
+
+void CustomToolsPlugin::setIsEnabled(bool enabled)
+{
+    d->enabled = enabled;
+}
+
+bool CustomToolsPlugin::isEnabled() const
+{
+    return d->enabled;
+}
